#ifndef LOCK_FILE_H
#define LOCK_FILE_H

#include <string>
#include "xunix.h"

class lock_file {

 public:

  // The constructor does NOT lock the file.
  lock_file(const std::string& filename);

  ~lock_file();

  // Be careful with lock() because a signal could interrupt our
  // waiting.  Sometimes that is what you want, and sometimes it isn't.
  // If it isn't what you want, use a try block to restart the lock()
  // call.
  void lock();

  void unlock();

 private:

  enum lock_state_t {
    LOCKED, UNLOCKED
  };

  int _fd;
  lock_state_t _lock_state;
  std::string _filename;
  struct flock _lock_flock;
  struct flock _unlock_flock;

};

#endif  /*  LOCK_FILE_H  */
